@@ -5,7 +5,6 @@ Visualization of an image.
 In the future, will add optional segmentation mesh overlay.
 """
 
-from . import cm
 import colorcet
 import matplotlib
 import collections
@@ -17,7 +16,7 @@ import numpy as np
 import ipywidgets as widgets
 from traitlets import CBool, CFloat, CInt, Unicode, CaselessStrEnum, List, validate, TraitError, Tuple
 from ipydatawidgets import NDArray, array_serialization, shape_constraints
-from .trait_types import ITKImage, ImagePointTrait, ImagePoint, PointSetList, PolyDataList, itkimage_serialization, image_point_serialization, polydata_list_serialization, Colormap
+from .trait_types import ITKImage, ImagePointTrait, ImagePoint, PointSetList, PolyDataList, itkimage_serialization, image_point_serialization, polydata_list_serialization, Colormap, LookupTable
 
 try:
     import ipywebrtc
@@ -116,8 +115,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.28.1').tag(sync=True)
-    _model_module_version = Unicode('^0.28.1').tag(sync=True)
+    _view_module_version = Unicode('^0.31.4').tag(sync=True)
+    _model_module_version = Unicode('^0.31.4').tag(sync=True)
     image = ITKImage(
         default_value=None,
         allow_none=True,
@@ -132,31 +131,42 @@ class Viewer(ViewerParent):
     _rendering_image = CBool(
         default_value=False,
         help="We are currently volume rendering the image.").tag(sync=True)
-    label_map = ITKImage(
+    label_image = ITKImage(
         default_value=None,
         allow_none=True,
         help="Label map for the image.").tag(
         sync=False,
         **itkimage_serialization)
-    rendered_label_map = ITKImage(
+    rendered_label_image = ITKImage(
         default_value=None,
         allow_none=True).tag(
         sync=True,
         **itkimage_serialization)
-    label_map_names = List(
-        trait=Tuple(),
+    label_image_names = List(
         allow_none=True,
         default_value=None,
         help="Names for labels in the label map.").tag(
-        sync=True)
-    label_map_weights = NDArray(dtype=np.float32, default_value=None, allow_none=True,
+        trait=Tuple(), sync=True)
+    label_image_blend = CFloat(
+        default_value=0.5,
+        help="Blend of the label map with the intensity image.").tag(sync=True)
+    label_image_weights = NDArray(dtype=np.float32, default_value=None, allow_none=True,
         help="Weights, from 0.0 to 1.0, for every label in the label map.")\
         .tag(sync=True, **array_serialization)\
         .valid(shape_constraints(None,))
     interpolation = CBool(
         default_value=True,
         help="Use linear interpolation in slicing planes.").tag(sync=True)
-    cmap = Colormap('Viridis (matplotlib)').tag(sync=True)
+    cmap = List(
+        default_value=None,
+        allow_none=True,
+        ).tag(trait=Colormap('Viridis (matplotlib)', allow_none=True), sync=True)
+    _custom_cmap = NDArray(dtype=np.float32, default_value=None, allow_none=True,
+                           help="RGB triples from 0.0 to 1.0 that define a custom linear, sequential colormap")\
+        .tag(sync=True, **array_serialization)\
+        .valid(shape_constraints(None, 3))
+    lut = LookupTable('glasbey',
+        help='Lookup table for the label map.').tag(sync=True)
     _custom_cmap = NDArray(dtype=np.float32, default_value=None, allow_none=True,
                            help="RGB triples from 0.0 to 1.0 that define a custom linear, sequential colormap")\
         .tag(sync=True, **array_serialization)\
@@ -189,7 +199,15 @@ class Viewer(ViewerParent):
     gradient_opacity = CFloat(
         default_value=0.2,
         help="Volume rendering gradient opacity, from (0.0, 1.0]").tag(sync=True)
-    blend = CaselessStrEnum(
+    opacity_gaussians = List(
+        default_value=None,
+        allow_none=True,
+        help="Volume opacity transfer function Gaussians parameters.").tag(sync=True)
+    channels = List(
+        default_value=None,
+        allow_none=True,
+        help="Components or channels enabled in a multi-component image.").tag(trait=CBool(), sync=True)
+    blend_mode = CaselessStrEnum(
         ('composite',
          'max',
          'min',
@@ -200,16 +218,16 @@ class Viewer(ViewerParent):
                   help="Region of interest: [[lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z]]")\
         .tag(sync=True, **array_serialization)\
         .valid(shape_constraints(2, 3))
-    vmin = CFloat(
+    vmin = List(
         default_value=None,
         allow_none=True,
         help="Value that maps to the minimum of image colormap.").tag(
-        sync=True)
-    vmax = CFloat(
+        trait=CFloat(), sync=True)
+    vmax = List(
         default_value=None,
         allow_none=True,
         help="Value that maps to the maximum of image colormap.").tag(
-        sync=True)
+        trait=CFloat(), sync=True)
     _largest_roi = NDArray(dtype=np.float64, default_value=np.zeros((2, 3), dtype=np.float64),
                            help="Largest possible region of interest: "
                            "[[lower_x, lower_y, lower_z), (upper_x, upper_y, upper_z]]")\
@@ -223,6 +241,8 @@ class Viewer(ViewerParent):
                             help="Size limit for 2D image visualization.").tag(sync=False)
     size_limit_3d = NDArray(dtype=np.int64, default_value=np.array([192, 192, 192], dtype=np.int64),
                             help="Size limit for 3D image visualization.").tag(sync=False)
+    sample_distance = CFloat(default_value=0.25,
+                            help="Normalized volume rendering sample distance.").tag(sync=True)
     _scale_factors = NDArray(dtype=np.uint8, default_value=np.array([1, 1, 1], dtype=np.uint8),
                              help="Image downscaling factors.").tag(sync=True, **array_serialization)
     _downsampling = CBool(default_value=False,
@@ -234,10 +254,9 @@ class Viewer(ViewerParent):
         help="Units to display in the scale bar.").tag(
         sync=True)
     point_set_representations = List(
-        trait=Unicode(),
         default_value=[],
         help="Point set representation").tag(
-        sync=True)
+        trait=Unicode(), sync=True)
     point_sets = PointSetList(
         default_value=None,
         allow_none=True,
@@ -252,11 +271,14 @@ class Viewer(ViewerParent):
                                   help="Opacities for the points sets")\
         .tag(sync=True, **array_serialization)\
         .valid(shape_constraints(None,))
+    point_set_sizes = NDArray(dtype=np.uint8, default_value=np.zeros((0,), dtype=np.uint8),
+                              help="Sizes for the points sets")\
+        .tag(sync=True, **array_serialization)\
+        .valid(shape_constraints(None,))
     point_set_representations = List(
-        trait=Unicode(),
         default_value=[],
         help="Point set representation").tag(
-        sync=True)
+        trait=Unicode(), sync=True)
     geometries = PolyDataList(
         default_value=None,
         allow_none=True,
@@ -297,6 +319,10 @@ class Viewer(ViewerParent):
                      "[view_up_x, view_up_y, view_up_z]]")\
         .tag(sync=True, **array_serialization)\
         .valid(shape_constraints(3, 3))
+    background = Tuple(
+        allow_none=True,
+        default_value=(),
+        help="Background color.").tag(trait=CFloat(), sync=True)
 
     def __init__(self, **kwargs):  # noqa: C901
         if 'point_set_colors' in kwargs:
@@ -307,6 +333,10 @@ class Viewer(ViewerParent):
             proposal = {'value': kwargs['point_set_opacities']}
             opacities_array = self._validate_point_set_opacities(proposal)
             kwargs['point_set_opacities'] = opacities_array
+        if 'point_set_sizes' in kwargs:
+            proposal = {'value': kwargs['point_set_sizes']}
+            sizes_array = self._validate_point_set_sizes(proposal)
+            kwargs['point_set_sizes'] = sizes_array
         if 'point_set_representations' in kwargs:
             proposal = {'value': kwargs['point_set_representations']}
             representations_list = self._validate_point_set_representations(
@@ -321,25 +351,32 @@ class Viewer(ViewerParent):
             proposal = {'value': kwargs['geometry_opacities']}
             opacities_array = self._validate_geometry_opacities(proposal)
             kwargs['geometry_opacities'] = opacities_array
+        if 'cmap' in kwargs and kwargs['cmap'] is not None:
+            proposal = {'value': kwargs['cmap']}
+            cmap_list = self._validate_cmap(proposal)
+            kwargs['cmap'] = cmap_list
+        if 'vmin' in kwargs and kwargs['vmin'] is not None:
+            proposal = {'value': kwargs['vmin']}
+            vmin_list = self._validate_vmin(proposal)
+            kwargs['vmin'] = vmin_list
+        if 'vmax' in kwargs and kwargs['vmax'] is not None:
+            proposal = {'value': kwargs['vmax']}
+            vmax_list = self._validate_vmax(proposal)
+            kwargs['vmax'] = vmax_list
         self.observe(self._on_geometries_changed, ['geometries'])
-        have_label_map = 'label_map' in kwargs and kwargs['label_map'] is not None
-        if have_label_map:
+        have_label_image = 'label_image' in kwargs and kwargs['label_image'] is not None
+        if have_label_image:
             # Interpolation is not currently supported with label maps
             kwargs['interpolation'] = False
-        if not 'cmap' in kwargs or kwargs['cmap'] is None:
-            if have_label_map:
-                kwargs['cmap'] = cm.grayscale
-            else:
-                kwargs['cmap'] = cm.viridis
 
         super(Viewer, self).__init__(**kwargs)
 
-        if not self.image and not self.label_map:
+        if not self.image and not self.label_image:
             return
         if self.image:
             image = self.image
         else:
-            image = self.label_map
+            image = self.label_image
         dimension = image.GetImageDimension()
         largest_region = image.GetLargestPossibleRegion()
         size = largest_region.GetSize()
@@ -347,7 +384,7 @@ class Viewer(ViewerParent):
         # Cache this so we do not need to recompute on it when resetting the
         # roi
         self._largest_roi_rendered_image = None
-        self._largest_roi_rendered_label_map = None
+        self._largest_roi_rendered_label_image = None
         self._largest_roi = np.zeros((2, 3), dtype=np.float64)
         if not np.any(self.roi):
             largest_index = largest_region.GetIndex()
@@ -366,19 +403,13 @@ class Viewer(ViewerParent):
             for dim in range(dimension):
                 if size[dim] > self.size_limit_3d[dim]:
                     self._downsampling = True
-        if self._downsampling and self.image:
-            self.extractor = itk.ExtractImageFilter.New(self.image)
-            self.shrinker = itk.BinShrinkImageFilter.New(self.extractor)
-        if self._downsampling and self.label_map:
-            self.label_map_extractor = itk.ExtractImageFilter.New(self.label_map)
-            self.label_map_shrinker = itk.ShrinkImageFilter.New(self.label_map_extractor)
         self._update_rendered_image()
         if self._downsampling:
             self.observe(self._on_roi_changed, ['roi'])
 
         self.observe(self._on_reset_crop_requested, ['_reset_crop_requested'])
-        self.observe(self.update_rendered_image, ['image', 'label_map'])
-        self.observe(self.update_rendered_image, ['image', 'label_map'])
+        self.observe(self.update_rendered_image, ['image', 'label_image'])
+        self.observe(self.update_rendered_image, ['image', 'label_image'])
 
     def _on_roi_changed(self, change=None):
         if self._downsampling:
@@ -389,7 +420,7 @@ class Viewer(ViewerParent):
             if self.image:
                 image = self.image
             else:
-                image = self.label_map
+                image = self.label_image
             dimension = image.GetImageDimension()
             largest_region = image.GetLargestPossibleRegion()
             size = largest_region.GetSize()
@@ -408,7 +439,7 @@ class Viewer(ViewerParent):
     @debounced(delay_seconds=0.2, method=True)
     def update_rendered_image(self, change=None):
         self._largest_roi_rendered_image = None
-        self._largest_roi_rendered_label_map = None
+        self._largest_roi_rendered_label_image = None
         self._largest_roi = np.zeros((2, 3), dtype=np.float64)
         self._update_rendered_image()
 
@@ -421,7 +452,7 @@ class Viewer(ViewerParent):
         return scale_factors
 
     def _update_rendered_image(self):
-        if self.image is None and self.label_map is None:
+        if self.image is None and self.label_image is None:
             return
         if self._rendering_image:
             @yield_for_change(self, '_rendering_image')
@@ -435,7 +466,7 @@ class Viewer(ViewerParent):
             if self.image:
                 image = self.image
             else:
-                image = self.label_map
+                image = self.label_image
             dimension = image.GetImageDimension()
             index = image.TransformPhysicalPointToIndex(
                 self.roi[0][:dimension])
@@ -451,9 +482,13 @@ class Viewer(ViewerParent):
                     self.size_limit_3d, dimension, size)
             self._scale_factors = np.array(scale_factors, dtype=np.uint8)
             if self.image:
+                self.extractor = itk.ExtractImageFilter.New(self.image)
+                self.shrinker = itk.ShrinkImageFilter.New(self.extractor)
                 self.shrinker.SetShrinkFactors(scale_factors[:dimension])
-            if self.label_map:
-                self.label_map_shrinker.SetShrinkFactors(scale_factors[:dimension])
+            if self.label_image:
+                self.label_image_extractor = itk.ExtractImageFilter.New(self.label_image)
+                self.label_image_shrinker = itk.ShrinkImageFilter.New(self.label_image_extractor)
+                self.label_image_shrinker.SetShrinkFactors(scale_factors[:dimension])
 
             region = itk.ImageRegion[dimension]()
             region.SetIndex(index)
@@ -466,9 +501,9 @@ class Viewer(ViewerParent):
             if self.image:
                 self.extractor.SetInput(self.image)
                 self.extractor.SetExtractionRegion(region)
-            if self.label_map:
-                self.label_map_extractor.SetInput(self.label_map)
-                self.label_map_extractor.SetExtractionRegion(region)
+            if self.label_image:
+                self.label_image_extractor.SetInput(self.label_image)
+                self.label_image_extractor.SetExtractionRegion(region)
 
             size = region.GetSize()
 
@@ -476,17 +511,17 @@ class Viewer(ViewerParent):
             if np.any(self._largest_roi) and np.all(
                     self._largest_roi == self.roi):
                 is_largest = True
-                if self._largest_roi_rendered_image is not None or self._largest_roi_rendered_label_map is not None:
+                if self._largest_roi_rendered_image is not None or self._largest_roi_rendered_label_image is not None:
                     if self.image:
                         self.rendered_image = self._largest_roi_rendered_image
-                    if self.label_map:
-                        self.rendered_label_map = self._largest_roi_rendered_label_map
+                    if self.label_image:
+                        self.rendered_label_image = self._largest_roi_rendered_label_image
                     return
 
             if self.image:
                 self.shrinker.UpdateLargestPossibleRegion()
-            if self.label_map:
-                self.label_map_shrinker.UpdateLargestPossibleRegion()
+            if self.label_image:
+                self.label_image_shrinker.UpdateLargestPossibleRegion()
             if is_largest:
                 if self.image:
                     self._largest_roi_rendered_image = self.shrinker.GetOutput()
@@ -494,40 +529,50 @@ class Viewer(ViewerParent):
                     self._largest_roi_rendered_image.SetOrigin(
                         self.roi[0][:dimension])
                     self.rendered_image = self._largest_roi_rendered_image
-                if self.label_map:
-                    self._largest_roi_rendered_label_map = self.label_map_shrinker.GetOutput()
-                    self._largest_roi_rendered_label_map.DisconnectPipeline()
-                    self._largest_roi_rendered_label_map.SetOrigin(
+                if self.label_image:
+                    self._largest_roi_rendered_label_image = self.label_image_shrinker.GetOutput()
+                    self._largest_roi_rendered_label_image.DisconnectPipeline()
+                    self._largest_roi_rendered_label_image.SetOrigin(
                         self.roi[0][:dimension])
-                    self.rendered_label_map = self._largest_roi_rendered_label_map
+                    self.rendered_label_image = self._largest_roi_rendered_label_image
                 return
             if self.image:
                 shrunk = self.shrinker.GetOutput()
                 shrunk.DisconnectPipeline()
                 shrunk.SetOrigin(self.roi[0][:dimension])
                 self.rendered_image = shrunk
-            if self.label_map:
-                shrunk = self.label_map_shrinker.GetOutput()
+            if self.label_image:
+                shrunk = self.label_image_shrinker.GetOutput()
                 shrunk.DisconnectPipeline()
                 shrunk.SetOrigin(self.roi[0][:dimension])
-                self.rendered_label_map = shrunk
+                self.rendered_label_image = shrunk
         else:
             if self.image:
                 self.rendered_image = self.image
-            if self.label_map:
-                self.rendered_label_map = self.label_map
+            if self.label_image:
+                self.rendered_label_image = self.label_image
 
-    @validate('label_map_weights')
-    def _validate_label_map_weights(self, proposal):
+    @validate('label_image_weights')
+    def _validate_label_image_weights(self, proposal):
         """Check the number of weights equals the number of labels."""
         value = proposal['value']
         value = np.array(value, dtype=np.float32)
-        if self.rendered_label_map:
-            labels = len(np.unique(itk.array_view_from_image(self.rendered_label_map)))
+        if self.rendered_label_image:
+            labels = len(np.unique(itk.array_view_from_image(self.rendered_label_image)))
             if labels != len(value):
                 raise TraitError('Number of labels, {0}, does not equal number of label weights, {1}'.format(labels, len(value)))
         return value
 
+    @validate('label_image_blend')
+    def _validate_label_image_blend(self, proposal):
+        """Enforce 0 <= value <= 1.0."""
+        value = proposal['value']
+        if value < 0.0:
+            return 0.0
+        if value > 1.0:
+            return 1.0
+        return value
+
     @validate('gradient_opacity')
     def _validate_gradient_opacity(self, proposal):
         """Enforce 0 < value <= 1.0."""
@@ -538,6 +583,46 @@ class Viewer(ViewerParent):
             return 1.0
         return value
 
+    @validate('label_image_blend')
+    def _validate_label_image_blend(self, proposal):
+        """Enforce 0 <= value <= 1.0."""
+        value = proposal['value']
+        if value < 0.0:
+            return 0.0
+        if value > 1.0:
+            return 1.0
+        return value
+
+    @validate('cmap')
+    def _validate_cmap(self, proposal):
+        value = proposal['value']
+        if value is None:
+            return None
+        elif isinstance(value, list):
+            return value
+        else:
+            return [value]
+
+    @validate('vmin')
+    def _validate_vmin(self, proposal):
+        value = proposal['value']
+        if value is None:
+            return None
+        elif isinstance(value, list):
+            return value
+        else:
+            return [value]
+
+    @validate('vmax')
+    def _validate_vmax(self, proposal):
+        value = proposal['value']
+        if value is None:
+            return None
+        elif isinstance(value, list):
+            return value
+        else:
+            return [value]
+
     @validate('point_set_colors')
     def _validate_point_set_colors(self, proposal):
         value = proposal['value']
@@ -568,6 +653,21 @@ class Viewer(ViewerParent):
         result[:n_values] = value
         return result
 
+    @validate('point_set_sizes')
+    def _validate_point_set_sizes(self, proposal):
+        value = proposal['value']
+        n_values = 0
+        if isinstance(value, float):
+            n_values = 1
+        else:
+            n_values = len(value)
+        n_sizes = n_values
+        if self.point_sets:
+            n_sizes = len(self.point_sets)
+        result = 3 * np.ones((n_sizes,), dtype=np.uint8)
+        result[:n_values] = value
+        return result
+
     @validate('point_set_representations')
     def _validate_point_set_representations(self, proposal):
         value = proposal['value']
@@ -590,6 +690,9 @@ class Viewer(ViewerParent):
         # Make sure we have a sufficient number of opacities
         old_opacities = self.point_set_opacities
         self.point_set_opacities = old_opacities[:len(self.point_sets)]
+        # Make sure we have a sufficient number of sizes
+        old_sizes = self.point_set_sizes
+        self.point_set_sizes = old_sizes[:len(self.point_sets)]
         # Make sure we have a sufficient number of representations
         old_representations = self.point_set_representations
         self.point_set_representations = old_representations[:len(
@@ -638,7 +741,7 @@ class Viewer(ViewerParent):
         if self.image:
             image = self.image
         else:
-            image = self.label_map
+            image = self.label_image
         dimension = image.GetImageDimension()
         index = image.TransformPhysicalPointToIndex(
             tuple(self.roi[0][:dimension]))
@@ -658,7 +761,7 @@ class Viewer(ViewerParent):
         if self.image:
             image = self.image
         else:
-            image = self.label_map
+            image = self.label_image
         dimension = image.GetImageDimension()
         region = self.roi_region()
         index = region.GetIndex()
@@ -670,16 +773,19 @@ class Viewer(ViewerParent):
 
 
 def view(image=None,  # noqa: C901
-         label_map=None,  # noqa: C901
-         label_map_names=None,  # noqa: C901
-         label_map_weights=None,  # noqa: C901
+         label_image=None,  # noqa: C901
+         label_image_names=None,  # noqa: C901
+         label_image_weights=None,  # noqa: C901
+         label_image_blend=0.5,
          cmap=None,
+         lut='glasbey',
          select_roi=False,
          interpolation=True,
-         gradient_opacity=0.22, slicing_planes=False, shadow=True, blend='composite',
+         gradient_opacity=0.22, opacity_gaussians=None, channels=None,
+         slicing_planes=False, shadow=True, blend_mode='composite',
          point_sets=[],
-         point_set_colors=[], point_set_opacities=[], point_set_representations=[],
-         # point_set_sizes=[],
+         point_set_colors=[], point_set_opacities=[],
+         point_set_representations=[], point_set_sizes=[],
          geometries=[],
          geometry_colors=[], geometry_opacities=[],
          ui_collapsed=False, rotate=False, annotations=True, mode='v',
@@ -733,6 +839,9 @@ def view(image=None,  # noqa: C901
              [focal_point_x, focal_point_y, focal_point_z],
              [view_up_x,     view_up_y,     view_up_z]]
 
+    background: (red, green, blue) tuple, components from 0.0 to 1.0
+        Background color. Default is based on the current Jupyter theme.
+
 
     Images
     ^^^^^^
@@ -740,26 +849,41 @@ def view(image=None,  # noqa: C901
     image : array_like, itk.Image, or vtk.vtkImageData
         The 2D or 3D image to visualize.
 
-    label_map : array_like, itk.Image, or vtk.vtkImageData
+    label_image : array_like, itk.Image, or vtk.vtkImageData
         The 2D or 3D label map to visualize. If an image is also provided, the
         label map must have the same size.
 
-    label_map_names : OrderedDict of (label_value, label_name)
+    label_image_names : OrderedDict of (label_value, label_name)
         String names associated with the integer label values.
 
-    label_map_weights : 1D numpy float32 array, default: None
+    label_image_weights : 1D numpy float32 array, default: None
         Rendering weights, from 0.0 to 1.0, associated labels in the label map.
 
-    vmin: float, default: None
-        Value that maps to the minimum of image colormap. Defaults to minimum of
-        the image pixel buffer.
+    label_image_blend : float, default: 0.5
+        Label map blend with intensity image, from 0.0 to 1.0.
 
-    vmax: float, default: None
-        Value that maps to the minimum of image colormap. Defaults to maximum of
-        the image pixel buffer.
+    vmin: list of floats, default: Minimum of the image pixel buffer
+        Value that maps to the minimum of image colormap. A single value
+        can be provided or a list for multi-component images.
 
-    cmap: string, default: viridis, grayscale with a label map
-        Colormap. Some valid values available at itkwidgets.cm.*
+    vmax: list of floats, default: Maximum of the image pixel buffer
+        Value that maps to the minimum of image colormap.  A single value can
+        be provided or a list for multi-component images.
+
+    cmap: list of colormaps
+            default:
+                - single component: 'viridis', 'grayscale' with a label map,
+                - two components: 'BkCy', 'BkMa'
+                - three components: 'BkRd', 'BkGn', 'BkBu'
+        Colormap for each image component. Some valid values available at
+        itkwidgets.cm.*
+        Colormaps can also be Nx3 float NumPy arrays from 0.0 to 1.0 for the
+        red, green, blue points on the map or a
+        matplotlib.colors.LinearSegmentedColormap.
+
+    lut: lookup table, default: 'glasbey'
+        Lookup table for the label map. Some valid values available at
+        itkwidgets.lut.*
 
     select_roi: bool, default: False
         Enable an interactive region of interest widget for the image.
@@ -783,10 +907,19 @@ def view(image=None,  # noqa: C901
     gradient_opacity: float, default: 0.22
         Gradient opacity for composite volume rendering, in the range (0.0, 1.0].
 
+    opacity_gaussians: list of list of dict
+        Volume rendering opacity transfer function Gaussian parameters. For each
+        image component, multiple Gaussians can be specified.
+        Default Gaussian parameters:
+          {'position': 0.5, 'height': 1, 'width': 0.5, 'xBias': 0.51, 'yBias': 0.4}
+
+    channels: list of booleans
+        For multi-component images, the components or channels that are enabled.
+
     shadow: bool, default: True
         Use shadowing with composite volume rendering.
 
-    blend: 'composite', 'max', 'min', or 'average', default: 'composite'
+    blend_mode: 'composite', 'max', 'min', or 'average', default: 'composite'
         Volume rendering blend mode.
 
     Point Sets
@@ -795,13 +928,16 @@ def view(image=None,  # noqa: C901
     point_sets: point set, or sequence of point sets
         The point sets to visualize.
 
-    point_set_colors: list of RGB colors
-        Colors for the N geometries. See help(matplotlib.colors) for
+    point_set_colors: list of (r, g, b) colors
+        Colors for the N points. See help(matplotlib.colors) for
         specification. Defaults to the Glasbey series of categorical colors.
 
-    point_set_opacities: list of floats, default: [0.5,]*n
+    point_set_opacities: array of floats, default: [1.0,]*n
         Opacity for the point sets, in the range (0.0, 1.0].
 
+    point_set_sizes: array of unsigned integers, default: [3,]*n
+        Sizes for the point sets, in pixel size units.
+
     point_set_representations: list of strings, default: ['points',]*n
         How to represent the point set. One of 'hidden', 'points', or 'spheres'.
 
@@ -836,6 +972,11 @@ def view(image=None,  # noqa: C901
         Size limit for 3D image visualization. If the roi is larger than this
         size, it will be downsampled for visualization.
 
+    sample_distance: float, default: 0.25
+        Sampling distance for volume rendering, normalized from 0.0 to 1.0.
+        Lower values result in a higher quality rendering. High values improve
+        the framerate.
+
     Returns
     -------
     viewer : ipywidget
@@ -915,18 +1056,23 @@ def view(image=None,  # noqa: C901
             image = images[0]
 
     viewer = Viewer(image=image,
-                    label_map=label_map,
-                    label_map_names=label_map_names,
-                    label_map_weights=label_map_weights,
+                    label_image=label_image,
+                    label_image_names=label_image_names,
+                    label_image_blend=label_image_blend,
+                    label_image_weights=label_image_weights,
                     cmap=cmap,
+                    lut=lut,
                     select_roi=select_roi,
                     interpolation=interpolation,
-                    gradient_opacity=gradient_opacity, slicing_planes=slicing_planes,
-                    shadow=shadow, blend=blend,
+                    gradient_opacity=gradient_opacity,
+                    opacity_gaussians=opacity_gaussians,
+                    slicing_planes=slicing_planes,
+                    shadow=shadow, blend_mode=blend_mode,
                     point_sets=point_sets,
                     point_set_colors=point_set_colors,
                     point_set_opacities=point_set_opacities,
                     point_set_representations=point_set_representations,
+                    point_set_sizes=point_set_sizes,
                     geometries=geometries, geometry_colors=geometry_colors, geometry_opacities=geometry_opacities,
                     rotate=rotate, ui_collapsed=ui_collapsed, annotations=annotations, mode=mode,
                     **kwargs)
